This function is similar to regrid except it performs a
multivariate transformation. This is useful, for instance, in multivariate
models that have a compositional response.
mvregrid(object, transform = "response", mult.name, newname = mult.name,
newlevs, fcn, ...)A new emmGrid object with the newly created factor as its last factor
An emmGrid object
The transformation to use in re-gridding. If "response",
we apply the inverse of the multivariate transformation in object@misc$tran;
otherwise, we re-grid as if transform had been applied to the multivariate
response. (Note that this will entail first re-gridding to the response scale
if necessary.)
The name of the multivariate factor to be transformed.
If missing, we use object@roles$multresp, and throw an error message
if it is NULL or ambiguous; in that case, the user must repeat the
call with mult.name specified.
the name to be given to the newly transformed variable
levels of the newly created factor (must conform to
the number of columns created by fcn). If missing, we use the column names
of the newly created variable.
The multivariate function to apply. If character, we look for it in the namespace of the compositions package.
Additional arguments passed to fcn
If a multivariate response transformation was used in fitting the model,
its name is auto-detected, and in that case we need not specify fcn
as long as its inverse can be found in the namespace of the compositions
package. (That package need not be installed unless fcn is a character
value.) For some such models, auto-detection process throws a
warning message, especially if cbind is also present in the model
formula.
Currently, no bias-adjustment option is available.
if(requireNamespace("compositions"))
emm_example("mvregrid")
# Use emm_example("mvregrid", list = TRUE) # to see just the code
Run the code above in your browser using DataLab